@@ -28,32 +28,28 @@ use function substr;
 use DateTimeImmutable;
 use DOMDocument;
 use SebastianBergmann\CodeCoverage\CodeCoverage;
-use SebastianBergmann\CodeCoverage\Driver\PathExistsButIsNotDirectoryException;
-use SebastianBergmann\CodeCoverage\Driver\WriteOperationFailedException;
 use SebastianBergmann\CodeCoverage\Node\AbstractNode;
 use SebastianBergmann\CodeCoverage\Node\Directory as DirectoryNode;
+use SebastianBergmann\CodeCoverage\Node\File;
 use SebastianBergmann\CodeCoverage\Node\File as FileNode;
+use SebastianBergmann\CodeCoverage\PathExistsButIsNotDirectoryException;
 use SebastianBergmann\CodeCoverage\Util\Filesystem as DirectoryUtil;
 use SebastianBergmann\CodeCoverage\Version;
+use SebastianBergmann\CodeCoverage\WriteOperationFailedException;
 use SebastianBergmann\CodeCoverage\XmlException;
 use SebastianBergmann\Environment\Runtime;
 
+/**
+ * @phpstan-import-type ProcessedClassType from File
+ * @phpstan-import-type ProcessedTraitType from File
+ * @phpstan-import-type ProcessedFunctionType from File
+ * @phpstan-import-type TestType from CodeCoverage
+ */
 final class Facade
 {
-    /**
-     * @var string
-     */
-    private $target;
-
-    /**
-     * @var Project
-     */
-    private $project;
-
-    /**
-     * @var string
-     */
-    private $phpUnitVersion;
+    private string $target;
+    private Project $project;
+    private readonly string $phpUnitVersion;
 
     public function __construct(string $version)
     {
@@ -75,7 +71,7 @@ final class Facade
         $report = $coverage->getReport();
 
         $this->project = new Project(
-            $coverage->getReport()->name()
+            $coverage->getReport()->name(),
         );
 
         $this->setBuildInformation();
@@ -100,6 +96,7 @@ final class Facade
     private function initTargetDirectory(string $directory): void
     {
         if (is_file($directory)) {
+            // @codeCoverageIgnoreStart
             if (!is_dir($directory)) {
                 throw new PathExistsButIsNotDirectoryException($directory);
             }
@@ -107,6 +104,7 @@ final class Facade
             if (!is_writable($directory)) {
                 throw new WriteOperationFailedException($directory);
             }
+            // @codeCoverageIgnoreEnd
         }
 
         DirectoryUtil::createDirectory($directory);
@@ -143,14 +141,14 @@ final class Facade
     {
         $fileObject = $context->addFile(
             $file->name(),
-            $file->id() . '.xml'
+            $file->id() . '.xml',
         );
 
         $this->setTotals($file, $fileObject->totals());
 
         $path = substr(
             $file->pathAsString(),
-            strlen($this->project->projectSourceDirectory())
+            strlen($this->project->projectSourceDirectory()),
         );
 
         $fileReport = new Report($path);
@@ -180,12 +178,15 @@ final class Facade
         }
 
         $fileReport->source()->setSourceCode(
-            file_get_contents($file->pathAsString())
+            file_get_contents($file->pathAsString()),
         );
 
         $this->saveDocument($fileReport->asDom(), $file->id());
     }
 
+    /**
+     * @param ProcessedClassType|ProcessedTraitType $unit
+     */
     private function processUnit(array $unit, Report $report): void
     {
         if (isset($unit['className'])) {
@@ -197,7 +198,7 @@ final class Facade
         $unitObject->setLines(
             $unit['startLine'],
             $unit['executableLines'],
-            $unit['executedLines']
+            $unit['executedLines'],
         );
 
         $unitObject->setCrap((float) $unit['crap']);
@@ -211,11 +212,14 @@ final class Facade
             $methodObject->setTotals(
                 (string) $method['executableLines'],
                 (string) $method['executedLines'],
-                (string) $method['coverage']
+                (string) $method['coverage'],
             );
         }
     }
 
+    /**
+     * @param ProcessedFunctionType $function
+     */
     private function processFunction(array $function, Report $report): void
     {
         $functionObject = $report->functionObject($function['functionName']);
@@ -226,6 +230,9 @@ final class Facade
         $functionObject->setTotals((string) $function['executableLines'], (string) $function['executedLines'], (string) $function['coverage']);
     }
 
+    /**
+     * @param array<string, TestType> $tests
+     */
     private function processTests(array $tests): void
     {
         $testsObject = $this->project->tests();
@@ -240,31 +247,31 @@ final class Facade
         $loc = $node->linesOfCode();
 
         $totals->setNumLines(
-            $loc['linesOfCode'],
-            $loc['commentLinesOfCode'],
-            $loc['nonCommentLinesOfCode'],
+            $loc->linesOfCode(),
+            $loc->commentLinesOfCode(),
+            $loc->nonCommentLinesOfCode(),
             $node->numberOfExecutableLines(),
-            $node->numberOfExecutedLines()
+            $node->numberOfExecutedLines(),
         );
 
         $totals->setNumClasses(
             $node->numberOfClasses(),
-            $node->numberOfTestedClasses()
+            $node->numberOfTestedClasses(),
         );
 
         $totals->setNumTraits(
             $node->numberOfTraits(),
-            $node->numberOfTestedTraits()
+            $node->numberOfTestedTraits(),
         );
 
         $totals->setNumMethods(
             $node->numberOfMethods(),
-            $node->numberOfTestedMethods()
+            $node->numberOfTestedMethods(),
         );
 
         $totals->setNumFunctions(
             $node->numberOfFunctions(),
-            $node->numberOfTestedFunctions()
+            $node->numberOfTestedFunctions(),
         );
     }
 
@@ -298,6 +305,7 @@ final class Facade
         $xml              = $document->saveXML();
 
         if ($xml === false) {
+            // @codeCoverageIgnoreStart
             $message = 'Unable to generate the XML';
 
             foreach (libxml_get_errors() as $error) {
@@ -305,6 +313,7 @@ final class Facade
             }
 
             throw new XmlException($message);
+            // @codeCoverageIgnoreEnd
         }
 
         libxml_clear_errors();
